@@ -26,6 +26,7 @@
  */
 
 /* revision history:
+ * 1.3.26a  2004/02/01   hof: added: gap_lib_alloc_ainfo_from_name
  * 1.3.25a  2004/01/20   hof: - removed xvpics support (gap_lib_get_video_paste_name)
  * 1.3.21e  2003/11/04   hof: - gimprc
  * 1.3.18a  2003/08/23   hof: - all gap_debug messages to stdout (do not mix with stderr)
@@ -873,6 +874,64 @@ gap_lib_exists_frame_nr(GapAnimInfo *ainfo_ptr, long nr, long *l_has_digits)
 }    /* end gap_lib_exists_frame_nr */
 
 
+/* ============================================================================
+ * gap_lib_alloc_ainfo_from_name
+ *
+ * allocate and init an ainfo structure from the given imagename
+ * (use this to get anim informations if none of the frame is not loaded
+ *  as image into the gimp
+ *  and no image_id is available)
+ * The ainfo_type is just a first guess. 
+ *  (check for videofiles GAP_AINFO_MOVIE is not supported here,
+ *   because this would require an video-api open attempt that would slow down)
+ * ============================================================================
+ */
+GapAnimInfo *
+gap_lib_alloc_ainfo_from_name(const char *imagename, GimpRunMode run_mode)
+{
+   GapAnimInfo   *l_ainfo_ptr;
+
+   if(imagename == NULL)
+   {
+     return (NULL);
+   }
+
+   l_ainfo_ptr = (GapAnimInfo*)g_malloc(sizeof(GapAnimInfo));
+   if(l_ainfo_ptr == NULL) return(NULL);
+
+   l_ainfo_ptr->basename = NULL;
+   l_ainfo_ptr->new_filename = NULL;
+   l_ainfo_ptr->extension = NULL;
+   l_ainfo_ptr->image_id = -1;
+
+   l_ainfo_ptr->old_filename = g_strdup(imagename);
+
+   l_ainfo_ptr->basename = gap_lib_alloc_basename(l_ainfo_ptr->old_filename, &l_ainfo_ptr->frame_nr);
+   if(NULL == l_ainfo_ptr->basename)
+   {
+       gap_lib_free_ainfo(&l_ainfo_ptr);
+       return(NULL);
+   }
+
+   l_ainfo_ptr->ainfo_type = GAP_AINFO_IMAGE;
+   if(l_ainfo_ptr->frame_nr > 0)
+   {
+     l_ainfo_ptr->ainfo_type = GAP_AINFO_FRAMES;
+   }
+   l_ainfo_ptr->extension = gap_lib_alloc_extension(l_ainfo_ptr->old_filename);
+
+   l_ainfo_ptr->curr_frame_nr = l_ainfo_ptr->frame_nr;
+   l_ainfo_ptr->first_frame_nr = -1;
+   l_ainfo_ptr->last_frame_nr = -1;
+   l_ainfo_ptr->frame_cnt = 0;
+   l_ainfo_ptr->run_mode = run_mode;
+
+
+   return(l_ainfo_ptr);
+
+}    /* end gap_lib_alloc_ainfo_from_name */
+
+
 /* ============================================================================
  * gap_lib_alloc_ainfo
  *
@@ -910,6 +969,11 @@ gap_lib_alloc_ainfo(gint32 image_id, GimpRunMode run_mode)
        return(NULL);
    }
 
+   l_ainfo_ptr->ainfo_type = GAP_AINFO_IMAGE;
+   if(l_ainfo_ptr->frame_nr > 0)
+   {
+     l_ainfo_ptr->ainfo_type = GAP_AINFO_FRAMES;
+   }
    l_ainfo_ptr->extension = gap_lib_alloc_extension(l_ainfo_ptr->old_filename);
 
    l_ainfo_ptr->curr_frame_nr = l_ainfo_ptr->frame_nr;
@@ -1592,7 +1656,7 @@ gap_lib_save_named_frame(gint32 image_id, char *sav_name)
     {
        l_rc = image_id;
     }
-    g_free(l_params);
+    gimp_destroy_params (l_params, l_retvals);
   }
   else
   {
